# -*- coding: utf-8 -*-

"""Main module."""


def ingredients(count):
    """Prints ingredients for making `count` arepas."""
    print(0.1*count, 'cups arepa flour')
    print(0.1*count, 'cups cheese')
    print(0.025*count, 'cups water')
